![Logo Tiramisu](logo.png "logo Tiramisu")

[Documentations](doc/README.md)


# LICENSES

See COPYING for the licences of the code and the documentation.

See AUTHORS for the details about the tiramisu's team.



